# pyaestro

`pyaestro` is a collection of data classes, data structures, and other utility 
classes that are aimed for use in workflow related code or tools. The goal of
`pyaestro` is to provide interfaces that allow developers to easily create 
code that can schedule jobs both locally and on widely available HPC schedulers
 as well as to be able to programmatically construct process flow and tracking.